@@ -21,19 +21,22 @@ import numpy as np
 from scipy.ndimage import map_coordinates
 
 _BASEDIR = Path(__file__).parent.resolve()
-LENS_FILE_PATH = _BASEDIR / "dpl_xy_z1_elliptical.npz"
-DEFAULT_CAM = 0
-DEFAULT_ZOOM = 0.07
 
 TITLE = "Face Lensing"
-COMMANDS = [
+COMMANDS = (
     "H : show/hide the app controls",
     "Q : shutdown app",
     "C : switch camera",
     "+ : increase lens effect",
     "- : decrease lens effect",
     "Space : take a screenshot",
-]
+)
+WATERMARK = "Made with Face Lensing - https://github.com/aboucaud/face_lensing"
+SCREENSHOT_TEMPLATE = "face_lensing_screenshot_{}.jpg"
+
+LENS_FILE_PATH = _BASEDIR / "dpl_xy_z1_elliptical.npz"
+DEFAULT_CAM = 0
+DEFAULT_ZOOM = 0.07
 
 
 class Camera:
@@ -46,7 +49,7 @@ class Camera:
         self._init_app()
 
     def _init_app(self):
-        self._save_counter = 0
+        self._save_count = 0
         self._show_help = False
         self.set_capture_device()
         self.read_image_properties()
@@ -68,24 +71,25 @@ class Camera:
         self._show_help = not self._show_help
 
     def show_commands(self, image):
-        ypos = 50
+        y_position = 50
         for i, cmd in enumerate(COMMANDS):
             cv2.putText(
                 img=image,
                 text=cmd,
-                org=(30, ypos + 30 * i),
+                org=(30, y_position + 30 * i),
                 fontFace=cv2.FONT_HERSHEY_SIMPLEX,
                 fontScale=0.8,
                 color=(240, 240, 240),
                 thickness=2,
             )
-            ypos += 30
+            y_position += 30
 
     def show(self, image=None):
         image = image if image is not None else self.read_capture_device()
         image = cv2.resize(image, self.output_shape)
         if self._show_help:
             self.show_commands(image)
+            self.add_watermark(image)
         cv2.imshow(TITLE, image)
 
     def switch_capture_device(self):
@@ -95,20 +99,23 @@ class Camera:
         self.read_image_properties()
 
     def take_screenshot(self, img):
-        img_name = f"face_lensing_screenshot_{self._save_counter}.jpg"
+        self.add_watermark(img)
+        img_name = SCREENSHOT_TEMPLATE.format(self._save_count)
         img_path = str(Path(self.output_dir) / img_name)
-        cv2.putText(
-            img=img,
-            text="Made with Face Lensing - CNRS",
-            org=(30, self.shape[0] - 30),
-            fontFace=cv2.FONT_HERSHEY_SIMPLEX,
-            fontScale=0.8,
-            color=(240, 240, 240),
-            thickness=2,
-        )
         cv2.imwrite(img_path, img)
-        self._save_counter += 1
         print(f"Image written as {img_path}")
+        self._save_count += 1
+
+    def add_watermark(self, image):
+        cv2.putText(
+            img=image,
+            text=WATERMARK,
+            org=(20, self.shape[0] - 20),
+            fontFace=cv2.FONT_HERSHEY_SIMPLEX,
+            fontScale=0.5,
+            color=(240, 240, 240),
+            thickness=1,
+        )
 
     def release(self):
         self.camera.release()
@@ -125,25 +132,22 @@ class Morphing:
 
     def read_morph_file(self, file_path):
         lens_model = np.load(file_path)
-        self.hx = lens_model["dplx"]
-        self.hy = lens_model["dply"]
-        self.shape = np.asarray(self.hx.shape, dtype=int)
+        self.dplx = lens_model["dplx"]
+        self.dply = lens_model["dply"]
+        self.shape = np.asarray(self.dplx.shape, dtype=int)
 
     def set_target_shape(self, new_shape):
         self.target_shape = np.asarray(new_shape, dtype=int)
+        self.coords = np.indices(new_shape)
         self.init_morphing()
 
     def init_morphing(self):
         lens_center = self.shape / 2
         img_center = self.target_shape / 2 + self.shift
 
-        self.Y, self.X = np.indices(self.target_shape)
-
         # Create coordinates mapping between the image and the lens
         centred_coords = (
-            np.indices(self.target_shape).reshape(2, -1)
-            - img_center[:, None]
-            + lens_center[:, None]
+            self.coords.reshape(2, -1) - img_center[:, None] + lens_center[:, None]
         ).astype(int)
 
         centred_coords[0] = centred_coords[0].clip(0, self.shape[0] - 1)
@@ -151,19 +155,22 @@ class Morphing:
 
         lens_coords = np.reshape(centred_coords, (2, *self.target_shape))
 
-        dpl1y = map_coordinates(self.hy / self.zoom, lens_coords, order=1)
-        dpl1x = map_coordinates(self.hx / self.zoom, lens_coords, order=1)
+        img_dply = map_coordinates(self.dply / self.zoom, lens_coords, order=1)
+        img_dplx = map_coordinates(self.dplx / self.zoom, lens_coords, order=1)
 
-        self.dply = np.array(self.Y - dpl1y).astype(int)
-        self.dplx = np.array(self.X - dpl1x).astype(int)
+        self.displacement_y = np.array(self.coords[0] - img_dply).astype(int)
+        self.displacement_x = np.array(self.coords[1] - img_dplx).astype(int)
         # Mirror lens effect on the horizontal axis
-        self.dplx = self.target_shape[1] - self.dplx
+        self.displacement_x = self.target_shape[1] - self.displacement_x
 
     def apply(self, image):
         return np.asarray(
             list(
                 map(
-                    lambda p, q: image[self.dply[p, q], self.dplx[p, q]], self.Y, self.X
+                    lambda iy, ix: image[
+                        self.displacement_y[iy, ix], self.displacement_x[iy, ix]
+                    ],
+                    *self.coords,
                 )
             )
         )
